==> ACE%2BTAO-5.7.2.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_attribute/set_from_extracted.h <==
//
// $Id: set_from_extracted.h 86020 2009-07-14 12:13:54Z wotte $
//
/* -*- c++ -*- */
// ============================================================================
//
// = LIBRARY
//    TAO IDL
//
// = FILENAME
//    set_from_extracted.h
//
// = DESCRIPTION
//    Encapsulation the variations in setting read/write
//    attributes from values extracted from an Any
//
// = AUTHOR
//    Jeff Parsons
//
// ============================================================================

#ifndef BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H
#define BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H

class be_visitor_attribute_set_from_extracted
  : public be_visitor_any_extracted_type_decl
{
  //
  // = TITLE
  //   be_visitor_attribute_set_from_extracted
  //
  // = DESCRIPTION
  //   Contains overloaded methods that emit arg values to be
  //   passed to an attribute mutator
  //
  //
public:
  be_visitor_attribute_set_from_extracted (be_visitor_context *ctx);
  virtual ~be_visitor_attribute_set_from_extracted (void);
  
  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);
};

#endif /* BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H */

==> ACE%2BTAO-6.2.3.tar.bz2: ACE_wrappers/TAO/TAO_IDL/be_include/be_visitor_attribute/set_from_extracted.h <==
/* -*- c++ -*- */
//=============================================================================
/**
 *  @file    set_from_extracted.h
 *
 *  $Id: set_from_extracted.h 93676 2011-03-29 12:25:33Z johnnyw $
 *
 *  Encapsulation the variations in setting read/write
 *  attributes from values extracted from an Any
 *
 *
 *  @author Jeff Parsons
 */
//=============================================================================


#ifndef BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H
#define BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H

/**
 * Contains overloaded methods that emit arg values to be
 * passed to an attribute mutator
 */
class be_visitor_attribute_set_from_extracted
  : public be_visitor_any_extracted_type_decl
{
public:
  be_visitor_attribute_set_from_extracted (be_visitor_context *ctx);
  virtual ~be_visitor_attribute_set_from_extracted (void);

  virtual int visit_array (be_array *);
  virtual int visit_component (be_component *);
  virtual int visit_enum (be_enum *);
  virtual int visit_eventtype (be_eventtype *);
  virtual int visit_home (be_home *);
  virtual int visit_interface (be_interface *);
  virtual int visit_predefined_type (be_predefined_type *);
  virtual int visit_sequence (be_sequence *);
  virtual int visit_string (be_string *);
  virtual int visit_structure (be_structure *);
  virtual int visit_typedef (be_typedef *);
  virtual int visit_union (be_union *);
  virtual int visit_valuebox (be_valuebox *);
  virtual int visit_valuetype (be_valuetype *);
};

#endif /* BE_VISITOR_ATTRIBUTE_SET_FROM_EXTRACTED_H */
